@@ -1,8 +1,13 @@
 """  Oracle Query Module
 
 """
-import json
+from __future__ import annotations
 
+import json
+from typing import Any
+from typing import Dict
+
+from clamfig import deserialize
 from clamfig import Serializable
 from web3 import Web3
 
@@ -20,12 +25,14 @@ class OracleQuery(Serializable):
     Each subclass corresponds to a unique Query Type supported
     by the TellorX network.
 
-    All public attributes of an OracleQuery represent an input that can
+    All public attributes of an OracleQuery represent a parameter that can
     be used to customize the query.
 
     The base class provides:
 
-    - Specification of the query `descriptor` JSON string.
+    - Generation of the query `descriptor` JSON string.
+    This string provides a simple platform and language independent
+    way to identify a query.
 
     - Calculation of the `id` field from `query_data`.  This value is used for the
       `TellorX.Oracle.tipQuery()` and `TellorX.Oracle.submitValue()`
@@ -78,3 +85,19 @@ class OracleQuery(Serializable):
         This method *must* be implemented by subclasses
         """
         raise NotImplementedError
+
+    @staticmethod
+    def get_query_from_data(query_data: bytes) -> OracleQuery:
+        """Recreate an oracle query from `query_data`"""
+        raise NotImplementedError
+
+
+def query_from_descriptor(descriptor: str) -> OracleQuery:
+    """Convert a query descriptor into a query object."""
+    state = json.loads(descriptor)
+    return query_from_state(state)
+
+
+def query_from_state(state: Dict[str, Any]) -> OracleQuery:
+    """Recreate a query object from it's JSON state."""
+    return deserialize(state)  # type: ignore
