@@ -10,12 +10,16 @@ from telliot_core.model.endpoints import RPCEndpoint
 logger = logging.getLogger(__name__)
 
 
-class PolygonTokenContract(Contract):
+class TokenContract(Contract):
     def __init__(self, node: RPCEndpoint, account: Optional[ChainedAccount] = None):
         chain_id = node.chain_id
         assert chain_id is not None
 
-        contract_info = contract_directory.find(chain_id=chain_id, name="polygon-token")[0]
+        if chain_id == 122:
+            contract_info = contract_directory.find(chain_id=chain_id, name="wrapped-fuse-token")[0]
+        else:
+            contract_info = contract_directory.find(chain_id=chain_id, name="trb-polygon-token")[0]
+
         if not contract_info:
             raise Exception(f"Tellorflex token contract not found on chain_id {chain_id}")
 
