@@ -1,7 +1,7 @@
 import pytest
 
 from telliot_core.apps.core import TelliotCore
-from telliot_core.tellor.tellorx.master import staker_status_map
+from telliot_core.tellor.tellorx.master import account_status_map
 from telliot_core.utils.timestamp import TimeStamp
 
 
@@ -17,5 +17,5 @@ async def test_get_staker_info(rinkeby_cfg):
         result, status = await tellorx.master.getStakerInfo(address)
         assert status.ok
         assert len(result) == 2
-        assert result[0] in staker_status_map.values()
+        assert result[0] in account_status_map.values()
         assert isinstance(result[1], TimeStamp)
