@@ -4,7 +4,7 @@ from click.testing import CliRunner
 import telliot_core.cli.main
 from telliot_core.apps.core import TelliotCore
 from telliot_core.data.query_catalog import query_catalog
-from telliot_core.queries import OracleQuery
+from telliot_core.queries.query import OracleQuery
 from telliot_core.reporters.reporter_utils import tellor_suggested_report
 
 
